@@ -341,6 +341,15 @@ def test_none_string(scorer):
     assert scorer(None, "test") == 0
 
 
+@pytest.mark.parametrize("scorer", scorers)
+def test_nan_string(scorer):
+    """
+    when float("nan") is passed to a scorer the result should always be 0
+    """
+    assert scorer("test", float("nan")) == 0
+    assert scorer(float("nan"), "test") == 0
+
+
 @pytest.mark.parametrize("scorer", scorers)
 def test_simple_unicode_tests(scorer):
     """
